==> ideaIC-213.7172.25-sources.jar: com/android/tools/idea/gradle/dsl/api/android/ProductFlavorModel.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.dsl.api.android;

import com.android.tools.idea.gradle.dsl.api.android.productFlavors.ExternalNativeBuildOptionsModel;
import com.android.tools.idea.gradle.dsl.api.android.productFlavors.NdkOptionsModel;
import com.android.tools.idea.gradle.dsl.api.android.productFlavors.VectorDrawablesOptionsModel;
import com.android.tools.idea.gradle.dsl.api.ext.ResolvedPropertyModel;
import org.jetbrains.annotations.NotNull;

import java.util.List;

public interface ProductFlavorModel extends FlavorTypeModel {
  @NotNull
  ResolvedPropertyModel applicationId();

  @NotNull
  ResolvedPropertyModel isDefault();

  @NotNull
  ResolvedPropertyModel dimension();

  @NotNull
  ExternalNativeBuildOptionsModel externalNativeBuild();

  void removeExternalNativeBuild();

  @NotNull
  ResolvedPropertyModel maxSdkVersion();

  @NotNull
  ResolvedPropertyModel minSdkVersion();

  /**
   * @return resolved property model representing a missing dimension strategy, this will be in the form of a LIST_TYPE with the first item
   * the dimension and the succeeding items the fallbacks. This property should be kept as a LIST_TYPE property. They can be deleted by
   * calling {@link ResolvedPropertyModel#delete()} on the strategy.
   */
  @NotNull
  List<ResolvedPropertyModel> missingDimensionStrategies();

  @NotNull
  ResolvedPropertyModel addMissingDimensionStrategy(@NotNull String dimension, @NotNull Object... fallbacks);

  /**
   * @return whether of new any missingDimensionStrategy has been changed, added or removed.
   */
  boolean areMissingDimensionStrategiesModified();

  @NotNull
  NdkOptionsModel ndk();

  void removeNdk();

  @NotNull
  ResolvedPropertyModel resConfigs();

  @NotNull
  ResolvedPropertyModel renderscriptTargetApi();

  @NotNull
  ResolvedPropertyModel renderscriptSupportModeEnabled();

  @NotNull
  ResolvedPropertyModel renderscriptSupportModelBlasEnabled();

  @NotNull
  ResolvedPropertyModel renderscriptNdkModeEnabled();

  @NotNull
  ResolvedPropertyModel targetSdkVersion();

  @NotNull
  ResolvedPropertyModel testApplicationId();

  @NotNull
  ResolvedPropertyModel testFunctionalTest();

  @NotNull
  ResolvedPropertyModel testHandleProfiling();

  @NotNull
  ResolvedPropertyModel testInstrumentationRunner();

  @NotNull
  ResolvedPropertyModel testInstrumentationRunnerArguments();

  @NotNull
  ResolvedPropertyModel versionCode();

  @NotNull
  ResolvedPropertyModel versionName();

  @NotNull
  VectorDrawablesOptionsModel vectorDrawables();

  @NotNull
  ResolvedPropertyModel wearAppUnbundled();
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/dsl/api/android/ProductFlavorModel.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.dsl.api.android;

import com.android.tools.idea.gradle.dsl.api.FlavorTypeModel;
import com.android.tools.idea.gradle.dsl.api.android.productFlavors.ExternalNativeBuildOptionsModel;
import com.android.tools.idea.gradle.dsl.api.android.productFlavors.NdkOptionsModel;
import com.android.tools.idea.gradle.dsl.api.ext.ResolvedPropertyModel;
import com.android.tools.idea.gradle.dsl.api.values.GradleNotNullValue;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Map;

public interface ProductFlavorModel extends FlavorTypeModel {
  @NotNull
  ResolvedPropertyModel applicationId();

  @NotNull
  ResolvedPropertyModel dimension();

  @NotNull
  ExternalNativeBuildOptionsModel externalNativeBuild();

  void removeExternalNativeBuild();

  @NotNull
  ResolvedPropertyModel maxSdkVersion();

  @NotNull
  ResolvedPropertyModel minSdkVersion();

  @NotNull
  NdkOptionsModel ndk();

  void removeNdk();

  @Nullable
  List<GradleNotNullValue<String>> resConfigs();

  void addResConfig(@NotNull String resConfig);

  void removeResConfig(@NotNull String resConfig);

  void removeAllResConfigs();

  void replaceResConfig(@NotNull String oldResConfig, @NotNull String newResConfig);

  @NotNull
  ResolvedPropertyModel targetSdkVersion();

  @NotNull
  ResolvedPropertyModel testApplicationId();

  @NotNull
  ResolvedPropertyModel testFunctionalTest();

  @NotNull
  ResolvedPropertyModel testHandleProfiling();

  @NotNull
  ResolvedPropertyModel testInstrumentationRunner();

  @Nullable
  Map<String, GradleNotNullValue<String>> testInstrumentationRunnerArguments();

  void setTestInstrumentationRunnerArgument(@NotNull String name, @NotNull String value);

  void removeTestInstrumentationRunnerArgument(@NotNull String name);

  void removeAllTestInstrumentationRunnerArguments();

  @NotNull
  ResolvedPropertyModel versionCode();

  @NotNull
  ResolvedPropertyModel versionName();
}
